(* $Id: test_bmp7.ml,v 1.4 2014/02/27 16:36:36 fclement Exp $ *)

open Grimage;;

let message s = print_string s; print_newline ();;

let wait () =
 message "\nPress return to continue";
 ignore (input_line stdin);;

let draw_ppm ppm = Graphics.draw_image (Graphics.make_image ppm);;
let load_ppm_file s = Ppm.load_ppm (Filename.concat "ppms" s);;
let save_ppm_file s ppm = Ppm.save_ppm (Filename.concat "ppms" s) ppm;;

let load_bmp_file s = Bmp.load_bmp (Filename.concat "bmps" s);;
let draw_bmp_file s = draw_bmp (load_bmp_file s);;

let draw_ppm_file s = draw_ppm (load_ppm_file s);;

let sz = 250;;
let sz_x = sz;;
let sz_y = sz - 100;;

open Graphics;;

open_graph (Printf.sprintf " %dx%d" sz_x sz_y);;

message "Drawing images using grimage ...";;

let x0, y0 = 0,2;;

draw_ppm_file "fumicaml.ppm" x0 y0;;

draw_bmp_file "JoeCaml.bmp" (x0 + 200) y0;;

message "Drawing with moveto lineto and more ...";;

(* Drawing a red rectangle. *)
let draw_poly v =
 let l = Array.length v in
  if l > 0 then begin
  let x0, y0 = current_point () in
  let p0 = v.(0) in
  let x, y = p0 in moveto x y;
  for i = 1 to l - 1 do
   let x, y = v.(i) in lineto x y
  done;
  lineto x y;
  moveto x0 y0
 end;;

set_color red;;

let p0 = x0 + 50, 2;;
draw_poly [| p0; (fst p0, 67); (fst p0 + 90, snd p0); p0 |];;

(* Drawing a strange logo by filling polygones. *)
(* Two equilateral triangles, one red and one blue, and their inside
   filled in black. *)
let logo_x, logo_y = x0 + 140, y0 + 30;;
let l = 40;;
let equi x y l =
 [| (x - l / 2, y);
    (x, y + int_of_float (float_of_int l *. (sqrt 3.0 /. 2.0)));
    (x + l / 2, y) |];;

set_color black;;
fill_poly
 (Array.append (equi logo_x logo_y l) (equi logo_x (logo_y + 24) (- l)));;

set_line_width 1;;
set_color cyan;;
draw_poly (equi logo_x logo_y l);;
set_color red;;
draw_poly (equi logo_x (logo_y + 24) (- l));;

(* Write a text in yellow on a blue background. *)
let sz_text = 10;;
let h = 20;;
set_text_size sz_text;;
set_color (rgb 150 100 250);;
let x_c, y_c = 17, 3;;
fill_rect (x_c - 6) (y_c + h / 2) (6 * 8 + 4) 25;;
set_color yellow;;
moveto x_c (y_c + h - 2);;
draw_string "Grimage";;

let save_screen_bmp f =
  Bmp.save_image f (get_image 0 0 (size_x ()) (size_y ()));; 

let save_screen_ppm f =
  Ppm.save_image f (get_image 0 0 (size_x ()) (size_y ()));; 

save_screen_bmp "grimage_logo.bmp";;

wait ();;
